==> swscanner_0.1.8.orig.tar.gz: swscanner-0.1.8/src/myevents.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Ivan Forcada Atienza                            *
 *   ivan@forcada.info                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef MYEVENTS_H
#define MYEVENTS_H

#include <qstring.h>
#include <qevent.h>
#include "gpserial.h"

enum personalEvents
{
  newPosEventNum = QCustomEvent::User,
  scanFinishedEventNum
};

class newPosEvent : public QCustomEvent
{
public:
    newPosEvent( geodata data ) : QCustomEvent( newPosEventNum ), pos( data ) {};
    geodata getPos() { return pos; };
    
private:
    geodata pos;
};

class scanFinishedEvent : public QCustomEvent
{
public:
	scanFinishedEvent() : QCustomEvent( scanFinishedEventNum ) {};
};

#endif

==> swscanner_0.2.2.orig.tar.gz: swscanner-0.2.2/src/myevents.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Ivan Forcada Atienza                            *
 *   ivan@forcada.info                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef MYEVENTS_H
#define MYEVENTS_H

#include <qstring.h>
#include <qevent.h>
#include "gpserial.h"
#include "apentry.h"

// Events I use:
enum personalEvents
{
	newGPSPositionEventNum = QCustomEvent::User,
	newSignalDataReceivedEventNum,
	scanFinishedEventNum,
	scanErrorEventNum,
	parseFinishedEventNum,
};

// Classes for the events:
class newGPSPositionEvent : public QCustomEvent
{
public:
    newGPSPositionEvent( geodata data ) : QCustomEvent( newGPSPositionEventNum ), pos( data ) {};
    geodata getPos() { return pos; };

private:
    geodata pos;
};

class scanFinishedEvent : public QCustomEvent
{
public:
	scanFinishedEvent() : QCustomEvent( scanFinishedEventNum ) {};
};

class scanErrorEvent : public QCustomEvent
{
public:
	scanErrorEvent(QString err) : QCustomEvent( scanErrorEventNum ), errorString (err) {};
	QString getError() { return errorString; };

private:
	QString errorString;
};

class newSignalDataReceivedEvent : public QCustomEvent
{
public:
	newSignalDataReceivedEvent(APEntry * AP) : QCustomEvent( newSignalDataReceivedEventNum ), AccessPoint( AP ) {};
	APEntry * getAccessPoint() { return AccessPoint; };
	
private: 
	APEntry * AccessPoint;
	
};

class parseFinishedEvent : public QCustomEvent
{
public:
	parseFinishedEvent() : QCustomEvent( parseFinishedEventNum ) {};
};

#endif
